summaryrefslogtreecommitdiffstats
path: root/kpdf/ui
diff options
context:
space:
mode:
Diffstat (limited to 'kpdf/ui')
-rw-r--r--kpdf/ui/minibar.cpp2
-rw-r--r--kpdf/ui/pageview.cpp26
-rw-r--r--kpdf/ui/pageview.h4
-rw-r--r--kpdf/ui/pageviewutils.cpp8
-rw-r--r--kpdf/ui/toc.cpp10
-rw-r--r--kpdf/ui/toc.h2
6 files changed, 26 insertions, 26 deletions
diff --git a/kpdf/ui/minibar.cpp b/kpdf/ui/minibar.cpp
index df3ebfce..c5d85cea 100644
--- a/kpdf/ui/minibar.cpp
+++ b/kpdf/ui/minibar.cpp
@@ -428,7 +428,7 @@ void HoverButton::paintEvent( TQPaintEvent * e )
else
{
TQPainter p( this );
- p.fillRect(e->rect(), tqparentWidget() ? tqparentWidget()->tqpalette().brush(TQPalette::Active, TQColorGroup::Background) : paletteBackgroundColor());
+ p.fillRect(e->rect(), parentWidget() ? parentWidget()->tqpalette().brush(TQPalette::Active, TQColorGroup::Background) : paletteBackgroundColor());
drawButtonLabel( &p );
}
}
diff --git a/kpdf/ui/pageview.h b/kpdf/ui/pageview.h
index 97114dcc..3bec8be0 100644
--- a/kpdf/ui/pageview.h
+++ b/kpdf/ui/pageview.h
@@ -101,7 +101,7 @@ class PageView : public TQScrollView, public DocumentObserver
void selectionStart( int x, int y, const TQColor & color, bool aboveAll = false );
void selectionEndPoint( int x, int y );
void selectionClear();
- // update internal zoom values and end in a slotRetqlayoutPages();
+ // update internal zoom values and end in a slotRelayoutPages();
void updateZoom( ZoomMode newZm );
// update the text on the label using global zoom value or current page's one
void updateZoomText();
@@ -115,7 +115,7 @@ class PageView : public TQScrollView, public DocumentObserver
private slots:
// activated either directly or via TQTimer on the viewportResizeEvent
- void slotRetqlayoutPages();
+ void slotRelayoutPages();
// activated either directly or via the contentsMoving(int,int) signal
void slotRequestVisiblePixmaps( int left = -1, int top = -1 );
// activated by the viewport move timer
diff --git a/kpdf/ui/pageviewutils.cpp b/kpdf/ui/pageviewutils.cpp
index ed5c637a..369bcd83 100644
--- a/kpdf/ui/pageviewutils.cpp
+++ b/kpdf/ui/pageviewutils.cpp
@@ -93,10 +93,10 @@ void PageViewMessage::display( const TQString & message, Icon icon, int duration
resize( tqgeometry.size() );
// create and set transparency tqmask
- TQPainter tqmaskPainter( &tqmask);
+ TQPainter maskPainter( &tqmask);
tqmask.fill( TQt::black );
- tqmaskPainter.setBrush( TQt::white );
- tqmaskPainter.drawRoundRect( tqgeometry, 1600 / tqgeometry.width(), 1600 / tqgeometry.height() );
+ maskPainter.setBrush( TQt::white );
+ maskPainter.drawRoundRect( tqgeometry, 1600 / tqgeometry.width(), 1600 / tqgeometry.height() );
setMask( tqmask );
// draw background
@@ -119,7 +119,7 @@ void PageViewMessage::display( const TQString & message, Icon icon, int duration
// if the tqlayout is RtL, we can move it to the right place only after we
// know how much size it will take
if ( TQApplication::reverseLayout() )
- move( tqparentWidget()->width() - tqgeometry.width() - 10, 10 );
+ move( parentWidget()->width() - tqgeometry.width() - 10, 10 );
// show widget and schedule a tqrepaint
show();
diff --git a/kpdf/ui/toc.cpp b/kpdf/ui/toc.cpp
index a453f20d..08880c3d 100644
--- a/kpdf/ui/toc.cpp
+++ b/kpdf/ui/toc.cpp
@@ -104,21 +104,21 @@ void TOC::notifySetup( const TQValueVector< KPDFPage * > & /*pages*/, bool docum
emit hasTOC( true );
}
-void TOC::addChildren( const TQDomNode & tqparentNode, KListViewItem * tqparentItem )
+void TOC::addChildren( const TQDomNode & parentNode, KListViewItem * parentItem )
{
// keep track of the current listViewItem
TOCItem * currentItem = 0;
- TQDomNode n = tqparentNode.firstChild();
+ TQDomNode n = parentNode.firstChild();
while( !n.isNull() )
{
// convert the node to an element (sure it is)
TQDomElement e = n.toElement();
- // insert the entry as top level (listview tqparented) or 2nd+ level
- if ( !tqparentItem )
+ // insert the entry as top level (listview parented) or 2nd+ level
+ if ( !parentItem )
currentItem = new TOCItem( this, currentItem, e );
else
- currentItem = new TOCItem( tqparentItem, currentItem, e );
+ currentItem = new TOCItem( parentItem, currentItem, e );
// descend recursively and advance to the next node
if ( e.hasChildNodes() )
diff --git a/kpdf/ui/toc.h b/kpdf/ui/toc.h
index 2d0c76d7..93824166 100644
--- a/kpdf/ui/toc.h
+++ b/kpdf/ui/toc.h
@@ -36,7 +36,7 @@ Q_OBJECT
void slotExecuted(TQListViewItem *i);
private:
- void addChildren( const TQDomNode & tqparentNode, KListViewItem * tqparentItem = 0 );
+ void addChildren( const TQDomNode & parentNode, KListViewItem * parentItem = 0 );
DocumentViewport getViewport( const TQDomElement &e ) const;
KPDFDocument *m_document;
};
diff --git a/kpdf/ui/pageview.cpp b/kpdf/ui/pageview.cpp
index 7172c6d3..27fe3fcb 100644
--- a/kpdf/ui/pageview.cpp
+++ b/kpdf/ui/pageview.cpp
@@ -173,7 +173,7 @@ void PageViewTip::maybeTip( const TQPoint &_p )
* 160 - constructor and creating actions plus their connected slots (empty stuff)
* 70 - DocumentObserver inherited methodes (important)
* 550 - events: mouse, keyboard, drag/drop
* 170 - slotRetqlayoutPages: set contents of the scrollview on continuous/single modes
* 100 - zoom: zooming pages in different ways, keeping update the toolbar actions, etc..
* other misc functions: only slotRequestVisiblePixmaps and pickItemOnPoint noticeable,
* and many insignificant stuff like this comment :-)
@@ -343,12 +343,12 @@ void PageView::notifySetup( const TQValueVector< KPDFPage * > & pageSet, bool do
d->items.push_back( new PageViewItem( *setIt ) );
if ( pageSet.count() > 0 )
// TODO for Enrico: Check if doing always the slotRetqlayoutPages() is not
// suboptimal in some cases, i'd say it is not but a recheck will not hurt
// Need slotRetqlayoutPages() here instead of d->dirtyLayout = true
// because opening a pdf from another pdf will not trigger a viewportchange
- // so pages are never retqlayouted
- TQTimer::singleShot(0, this, TQT_SLOT(slotRetqlayoutPages()));
+ // so pages are never relayouted
+ TQTimer::singleShot(0, this, TQT_SLOT(slotRelayoutPages()));
else
{
// update the mouse cursor when closing because we may have close through a link and
@@ -395,7 +395,7 @@ void PageView::notifyViewportChanged( bool smoothMove )
// retqlayout in "Single Pages" mode or if a retqlayout is pending
d->blockPixmapsRequest = true;
if ( !KpdfSettings::viewContinuous() || d->dirtyLayout )
- slotRetqlayoutPages();
+ slotRelayoutPages();
// restore viewport center or use default {x-center,v-top} tqalignment
const TQRect & r = item->tqgeometry();
@@ -637,7 +637,7 @@ void PageView::viewportResizeEvent( TQResizeEvent * )
if ( !d->delayResizeTimer )
{
d->delayResizeTimer = new TQTimer( this );
- connect( d->delayResizeTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( slotRetqlayoutPages() ) );
+ connect( d->delayResizeTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( slotRelayoutPages() ) );
}
d->delayResizeTimer->start( 333, true );
}
@@ -1550,7 +1550,7 @@ void PageView::updateZoom( ZoomMode newZoomMode )
// be sure to block updates to document's viewport
bool prevState = d->blockViewport;
d->blockViewport = true;
- slotRetqlayoutPages();
+ slotRelayoutPages();
d->blockViewport = prevState;
// request pixmaps
slotRequestVisiblePixmaps();
@@ -1649,7 +1649,7 @@ void PageView::doTypeAheadSearch()
}
//BEGIN private SLOTS
-void PageView::slotRetqlayoutPages()
+void PageView::slotRelayoutPages()
// called by: notifySetup, viewportResizeEvent, slotTwoPagesToggled, slotContinuousToggled, updateZoom
{
// set an empty container if we have no pages
@@ -2070,7 +2070,7 @@ void PageView::slotRotateRight()
// be sure to block updates to document's viewport
bool prevState = d->blockViewport;
d->blockViewport = true;
- slotRetqlayoutPages();
+ slotRelayoutPages();
d->blockViewport = prevState;
// request pixmaps
slotRequestVisiblePixmaps();
@@ -2094,7 +2094,7 @@ void PageView::slotRotateLeft()
// be sure to block updates to document's viewport
bool prevState = d->blockViewport;
d->blockViewport = true;
- slotRetqlayoutPages();
+ slotRelayoutPages();
d->blockViewport = prevState;
// request pixmaps
slotRequestVisiblePixmaps();
@@ -2108,7 +2108,7 @@ void PageView::slotTwoPagesToggled( bool on )
KpdfSettings::setViewColumns( newColumns );
KpdfSettings::writeConfig();
if ( d->document->pages() > 0 )
- slotRetqlayoutPages();
+ slotRelayoutPages();
}
}
@@ -2119,7 +2119,7 @@ void PageView::slotContinuousToggled( bool on )
KpdfSettings::setViewContinuous( on );
KpdfSettings::writeConfig();
if ( d->document->pages() > 0 )
- slotRetqlayoutPages();
+ slotRelayoutPages();
}
}
@@ -173,7 +173,7 @@ void PageViewTip::maybeTip( const TQPoint &_p )
* 70 - DocumentObserver inherited methodes (important)
* 550 - events: mouse, keyboard, drag/drop
- * 170 - slotRetqlayoutPages: set contents of the scrollview on continuous/single modes
+ * 170 - slotRelayoutPages: set contents of the scrollview on continuous/single modes
* 100 - zoom: zooming pages in different ways, keeping update the toolbar actions, etc..
* other misc functions: only slotRequestVisiblePixmaps and pickItemOnPoint noticeable,
@@ -343,12 +343,12 @@ void PageView::notifySetup( const TQValueVector< KPDFPage * > & pageSet, bool do
d->items.push_back( new PageViewItem( *setIt ) );
if ( pageSet.count() > 0 )
- // TODO for Enrico: Check if doing always the slotRetqlayoutPages() is not
+ // TODO for Enrico: Check if doing always the slotRelayoutPages() is not
// suboptimal in some cases, i'd say it is not but a recheck will not hurt
@@ -343,12 +343,12 @@ void PageView::notifySetup( const TQValueVector< KPDFPage * > & pageSet, bool do
// suboptimal in some cases, i'd say it is not but a recheck will not hurt
- // Need slotRetqlayoutPages() here instead of d->dirtyLayout = true
+ // Need slotRelayoutPages() here instead of d->dirtyLayout = true
// because opening a pdf from another pdf will not trigger a viewportchange